# WebExtensions, web_accessible_resources, .javascript, and macOS file associations issue: Extension 2

## Overview

It sounds strange, but loading a `.javascript` file from a WebExtension's [web_accessible_resources](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/manifest.json/web_accessible_resources) somehow causes problems with the macOS file associations, most notable so with TextMate 2.

This Gist contains a simple Web Extension and instructions to reproduce the issue.


## Tested On

-   macOS 10.13.3 - 10.13.4 (native and in a clean VM)
-   Firefox 59.0.1 - 59.0.2 (Stable)
-   Firefox 60.0b5 - 60.0b8 (Developer Edition)
-   Several previous Firefox versions


## Regression Info

Info from mozregression testing:

- Last good revision: ba8db0fbc00605d6d097dde0b7e034297f55c1ec
- First bad revision: 6b101438c684bff925471edbfe593e500bcb3a03
- Pushlog:
https://hg.mozilla.org/integration/autoland/pushloghtml?fromchange=ba8db0fbc00605d6d097dde0b7e034297f55c1ec&tochange=6b101438c684bff925471edbfe593e500bcb3a03

Commands to run revisions:

```sh
mozregression --repo autoland --launch ba8db0fbc00605d6d097dde0b7e034297f55c1ec
mozregression --repo autoland --launch 6b101438c684bff925471edbfe593e500bcb3a03
```


## Reproduce Instructions

1.  Download this Gist if you have not already.
2.  Install [TextMate 2 RC 8](https://github.com/textmate/textmate/releases/download/v2.0-rc.8/TextMate_2.0-rc.8.tbz) (exact version probably does not matter).
3.  In Finder navigate to the Gist, select `file.js` and `file.txt`, click File > Get Info, and set all of them to open with TextMate, making sure to click "Change All" for each one.
4.  Make sure TextMate is not running, then open Firefox 59.0.1 (exact version probably does not matter), ideally with a new profile.
5.  Go to `about:debugging`, click "Load Temporary Add-On" and open the `manifest.json` file in this Gist.
6.  Verify in Finder that TextMate is still the default editor for `.js`, and `.txt` files.
7.  Go to page like example.com and click the button this extension added to the UI.
8.  In Finder, select `file.js`, and `file.txt` again and click File > Get Info and see that it has changed (you can also try opening them to confirm it has changed).
9.  Open TextMate.
10. Repeat step 8 to see it has actually changed back.


## Notes

-   May be necessary to relaunch Firefox to repeat the test.
-   You can edit `background.js` to load `war-test.js` instead of `war-test.javascript` and see the issue no longer happens.
-   Other extensions do not seem to cause the problem, it seems something is special about the `.javascript` extension.
-   If the `moz-extension://` URL is known and added to the DOM, it is possible to trigger the issue without a `onBeforeRequest` redirect.
-   Requests to `.javascript` files outside of `web_accessible_resources` does not cause an issue.
